@@ -1,11 +1,13 @@
 from click import command, argument
-from ..utils import load_template
-from ..defaults import TEMPLATE_EXTS
+
+from cloudinary_cli.defaults import TEMPLATE_EXTS, logger
+from cloudinary_cli.utils import load_template
+
 
 @command("make", short_help="Scaffold Cloudinary templates.",
          help="""\b
-Scaffold Cloudinary templates.
-eg. cld make product gallery
+Returns template code for implementing the specified Cloudinary widget.
+e.g. cld make product_gallery
 """)
 @argument("template", nargs=-1)
 def make(template):
@@ -16,4 +18,8 @@ def make(template):
     elif template[0] in TEMPLATE_EXTS.keys():
         language = template[0]
         template = template[1:]
-    print(load_template(language, '_'.join(template)))
+    try:
+        src = load_template(language, '_'.join(template))
+        print(src)
+    except Exception as e:
+        logger.error(e)
